# Lattest indonesian earthquake 

## HOW IT WORK?

This package will scrape from [BMKG](https://bmkg.go.id) to get lattest report earthquake in indonesian

This package use BeautifulSoup4 and Requests,  it can produce output in JSON that is ready to be used in web or mobile applications